#! /usr/bin/python
"""process_csvs.py: Process csv files to format the results presented in Euro-par 2020 paper"""
__author__      = "Sohan Lal"

import sys
import os
import csv
import itertools
import pandas as pd

# Point to the directory where the input CSV is and output CSV should be. Default is the current directory
file_path = r"./"
out_file_path = r"./"

# Filter list to selected required benchmarks for plotting
filter_list_GPU_CPU = ['# Benchmark name','MicroBench','Pattern','Runtime_Blocked','Runtime_DAG','Runtime_Ind','NBody', 'Kmeans','VectorAddition_fp32','ScalarProduct_NDRange_fp32','ScalarProduct_Hierarchical_fp32','MatmulChain']

filter_list_SYCL_Runtime = ['# Benchmark name','Runtime_Ind']

selected_rows = []
def sortFunc(e):
	return e[0].startswith('Polybench')

def process_csvs_perf(csv_file_to_process, processed_outfile, filter_list):
    with open(processed_outfile, 'wb+') as csvfile:
        op_csv = csv.writer(csvfile,delimiter=',', escapechar=' ', quoting=csv.QUOTE_NONE)
        with open(csv_file_to_process, 'rb') as readcsv:
            csvreader = csv.reader(readcsv, delimiter=',', escapechar='\n', quoting=csv.QUOTE_NONE)
            i = 0
            for row in csvreader:
			    flag = False
			    for item in filter_list:
				    if (row[0].startswith(item) or row[0].endswith('64')):
					    flag = True
			    if flag and i != 0:
				    continue
			    else:
				    i = i+1
				    selected_rows.append(row)
	    selected_rows.sort()
	    selected_rows.sort(key=sortFunc)
	    for bench in selected_rows:
		    op_csv.writerow(bench)

# Extend to extend in future
def process_csvs_sycl_runtime(csv_file_to_process, processed_outfile, filter_list):
    return 0;

if len(sys.argv) < 3:
    print 'Usage:process_csvs.py choice input_csv'
    print 'Please input choice to process csv for performance/SYCL runtime plots'
    print '0 = Process hipSYCL GPU file'
    print '1 = Process ComputeCpp GPU file'
    print '2 = Process hipSYCL CPU file'
    print '3 = Process ComputeCpp CPU file'
    sys.exit()

choice = int(sys.argv[1])
csv_file_to_process = sys.argv[2]

if choice == 0:
    print 'hipSYCL GPU file selected to process '
    #csv_file_to_process = os.path.join(file_path, 'sycl-bench-hipSYCL-GPU.csv')
    processed_outfile = os.path.join(out_file_path, 'hipSYCL-sycl-bench-GPU.csv')
    filter_list = filter_list_GPU_CPU
elif choice == 1:
    print 'ComputeCpp GPU file selected to process '
    #csv_file_to_process = os.path.join(file_path, 'sycl-bench-ComputeCpp-GPU.csv')
    processed_outfile = os.path.join(out_file_path, 'ComputeCpp-sycl-bench-GPU.csv')
    filter_list = filter_list_GPU_CPU
elif choice == 2:
    print 'hipSYCL CPU file selected to process '
    #csv_file_to_process = os.path.join(file_path, 'sycl-bench-hipSYCL-CPU.csv')
    processed_outfile = os.path.join(out_file_path, 'hipSYCL-sycl-bench-CPU.csv')
    filter_list = filter_list_GPU_CPU
elif choice == 3:
    print 'ComputeCpp CPU file selected to process '
    #csv_file_to_process = os.path.join(file_path, 'sycl-bench-ComputeCpp-CPU.csv')
    processed_outfile = os.path.join(out_file_path, 'ComputeCpp-sycl-bench-CPU.csv')
    filter_list = filter_list_GPU_CPU
else:
    print 'Please input proper choice'
    sys.exit()

if (choice == 0 or choice == 1 or choice == 2 or choice ==3):
    process_csvs_perf(csv_file_to_process, processed_outfile, filter_list)
else:
    # Extend to other cases
    process_csvs_sycl_runtime(csv_file_to_process, processed_outfile, filter_list)
    
        

  
