#!/usr/bin/python
"""runTimehipSYCL-ComputeCpp-Stacked-GPU.py: Plot hipSYCL vs ComputeCPP runtime on GPU."""
__author__      = "Sohan Lal"

import pandas as pd
import matplotlib.pyplot as plt
import numpy as np
plt.rcParams['text.usetex'] = True
plt.rcParams['text.latex.preamble'] = [r'\usepackage{sansmath}', r'\sansmath'] #Force sans-serif math mode (for axes labels)
plt.rcParams['font.family'] = 'sans-serif' # ... for regular text
plt.rcParams['font.sans-serif'] = 'Helvetica' # Choose a nice font here

# matplotlib settings
plt.style.use('default') # reset
plt.style.use('seaborn-deep')

bench_abbrevs = ['LRC', 'LRE','MEDIAN', 'MD', 'SPH', 'SPND', 'SOBEL3', 'SOBEL5', 'SOBEL7', 'VA', '2DCON', '2MM', '3DCON', '3MM', 'ATAX', 'BICG', 'CORR', 'COV', 'FTD2D','GEMM', 'GESUM', 'GRAMS', 'MVT', 'SYR2K', 'SYRK','Average']

hipSYCL = pd.read_csv('./hipSYCL-sycl-bench-GPU.csv', header=None, skiprows = 1)
computeCpp = pd.read_csv('./ComputeCpp-sycl-bench-GPU.csv', header=None, skiprows = 1)

#hipSYCL execution time
hipSYCL_exe_time = hipSYCL[12].copy(deep=True)

#Add last colums as average
hipSYCL_exe_time[len(hipSYCL_exe_time)] = hipSYCL[12].mean()

computeCpp_exe_time_kernel_only = computeCpp[4].copy(deep=True)

computeCpp_exe_time_delta = (computeCpp[12] - computeCpp[4]).copy(deep=True)

#Add last colums as average
computeCpp_exe_time_kernel_only[len(computeCpp_exe_time_kernel_only)] = computeCpp[4].mean()

#Add last colums as average
computeCpp_exe_time_delta[len(computeCpp_exe_time_delta)] = (computeCpp[12].mean() - computeCpp[4].mean())

# Setting the positions and width for the bars
pos = list(range(len(bench_abbrevs)))
width = 0.25

# Plotting the bars
fig, ax = plt.subplots(figsize=(10,3))

# Create a bar with pre_score data,
# in position pos,

# Create a bar with mid_score data,
# in position pos + some width buffer,

plt.bar(pos,
        #using df['mid_score'] data,
        computeCpp_exe_time_kernel_only,
        # of width
        width,
        # with alpha 0.5
        alpha=1.0,
        # with color
        color='lightgray',
		hatch = '////',
        # with label the second value in first_name
        label='xBW')

plt.bar(pos,
        #using df['mid_score'] data,
        computeCpp_exe_time_delta,
        # of width
        width,
        bottom=computeCpp_exe_time_kernel_only,
        # with alpha 0.5
        alpha=1.0,
        # with color
        color='#4C72B0',
		hatch = '////',
        # with label the second value in first_name
        label='xBW')

plt.bar([p + width for p in pos],
        #using df['pre_score'] data,
        hipSYCL_exe_time,
        # of width
        width,
        # with alpha 0.5
        alpha=1.0,
        # with color
        color='#55A868',
        # with label the first value in first_name
        label='xBW')

# Set the y axis label
ax.set_ylabel('Execution Time [s]')

# Set the position of the x ticks
ax.set_xticks([p + 0.5 * width for p in pos])

# Set the labels for the x ticks
ax.set_xticklabels(bench_abbrevs, rotation = 45)

# Setting the x-axis and y-axis limits
plt.xlim(min(pos)-2*width, max(pos)+width*3)
plt.ylim([0.0001,40])

ax.set_yscale('log')

ax.yaxis.grid(True, color='lightgray')
ax.set_axisbelow(True)

# Adding the legend and showing the plot
plt.legend(['Kernel-Only','ComputeCpp PTX','hipSYCL'], ncol=3, loc='upper right')
#plt.grid()
plt.savefig('runtime_hipSYCL_ComputeCpp_stacked_GPU.pdf',bbox_inches='tight')
plt.savefig('runtime_hipSYCL_ComputeCpp_stacked_GPU.png',bbox_inches='tight', dpi = 300)
#plt.show()
